@@ -42,4 +42,12 @@ def test_plotting():
 
   assert round(Image.open("test1.png").width / 96 * 2.54, 1) == 15.5, "Large figure is not the correct width (pixels × DPI)"
   assert round(Image.open("test2.png").width / 96 * 2.54, 1) == 7.6, "Small figure is not the correct width (pixels × DPI)"
+  
+def test_yaxis_title():
+  dt.REFERENCE_DATABASE = dt.Gdx("test.gdx")
+  s = dt.Gdx("test.gdx")
+  df = dt.DataFrame(s.qY, "m")
+  assert df.plot().layout.yaxis.title.text == ""
+  assert df.plot(layout=dict(yaxis_title="y-axis title")).layout.yaxis.title.text == ""
+  assert df.plot(layout=dict(yaxis_title="y-axis title"), horizontal_yaxis_title=False).layout.yaxis.title.text == "y-axis title"
   
\ No newline at end of file
